package com.sun.xml.internal.org.jvnet.mimepull;

import java.nio.ByteBuffer;

abstract class MIMEEvent
{
    static final MIMEEvent.StartMessage START_MESSAGE;
    static final MIMEEvent.StartPart START_PART;
    static final MIMEEvent.EndPart END_PART;
    static final MIMEEvent.EndMessage END_MESSAGE;
    
    MIMEEvent() {
    }
    
    abstract MIMEEvent.EVENT_TYPE getEventType();
    
    static {
        START_MESSAGE = new MIMEEvent.StartMessage();
        START_PART = new MIMEEvent.StartPart();
        END_PART = new MIMEEvent.EndPart();
        END_MESSAGE = new MIMEEvent.EndMessage();
    }
    
    enum EVENT_TYPE
    {
        START_MESSAGE, 
        START_PART, 
        HEADERS, 
        CONTENT, 
        END_PART, 
        END_MESSAGE;
    }
    
    static final class StartMessage extends MIMEEvent
    {
        @Override
        MIMEEvent.EVENT_TYPE getEventType() {
            return MIMEEvent.EVENT_TYPE.START_MESSAGE;
        }
    }
    
    static final class StartPart extends MIMEEvent
    {
        @Override
        MIMEEvent.EVENT_TYPE getEventType() {
            return MIMEEvent.EVENT_TYPE.START_PART;
        }
    }
    
    static final class EndPart extends MIMEEvent
    {
        @Override
        MIMEEvent.EVENT_TYPE getEventType() {
            return MIMEEvent.EVENT_TYPE.END_PART;
        }
    }
    
    static final class Headers extends MIMEEvent
    {
        InternetHeaders ih;
        
        Headers(InternetHeaders ih) {
            this.ih = ih;
        }
        
        @Override
        MIMEEvent.EVENT_TYPE getEventType() {
            return MIMEEvent.EVENT_TYPE.HEADERS;
        }
        
        InternetHeaders getHeaders() {
            return this.ih;
        }
    }
    
    static final class Content extends MIMEEvent
    {
        private final ByteBuffer buf;
        
        Content(ByteBuffer buf) {
            this.buf = buf;
        }
        
        @Override
        MIMEEvent.EVENT_TYPE getEventType() {
            return MIMEEvent.EVENT_TYPE.CONTENT;
        }
        
        ByteBuffer getData() {
            return this.buf;
        }
    }
    
    static final class EndMessage extends MIMEEvent
    {
        @Override
        MIMEEvent.EVENT_TYPE getEventType() {
            return MIMEEvent.EVENT_TYPE.END_MESSAGE;
        }
    }
}
